@@ -18,10 +18,11 @@ export NO_PROXY=$no_proxy,$(minikube ip)
 #starting the minikube dashboard
 timeout 5s minikube dashboard
 
-echo -e "\e[1;32mminkube dashboard can be accessed using:\e[0m"
-echo -e "\e[1;35mhttp://$HOST_IP:8001/api/v1/namespaces/kubernetes-dashboard/services/http:kubernetes-dashboard:/proxy/#/workloads?namespace=default\e[0m"
+echo -e "\e[1;32mminikube dashboard can be accessed using:\e[0m"
+echo -e "\e[1;35mhttp://$HOST_IP:8001/api/v1/namespaces/kubernetes-dashboard/services/http:kubernetes-dashboard:/proxy/\e[0m"
 #enabling proxy
+nohup kubectl proxy --address="0.0.0.0" --disable-filter=true & >/dev/null &
+sleep 10s
 
-kubectl proxy --address="0.0.0.0" --disable-filter=true &
 
 
